import { Connection, Transaction } from "@solana/web3.js";
import { MsgExecuteContract } from "@terra-money/terra.js";
import { MsgExecuteContract as MsgExecuteContractInjective } from "@injectivelabs/sdk-ts";
import { Algodv2 } from "algosdk";
import { Account as nearAccount } from "near-api-js";
import { ethers, PayableOverrides } from "ethers";
import { TransactionSignerPair } from "../algorand";
export declare function attestFromEth(tokenBridgeAddress: string, signer: ethers.Signer, tokenAddress: string, overrides?: PayableOverrides & {
    from?: string | Promise<string>;
}): Promise<ethers.ContractReceipt>;
export declare function attestFromTerra(tokenBridgeAddress: string, walletAddress: string, asset: string): Promise<MsgExecuteContract>;
/**
 * Creates attestation message
 * @param tokenBridgeAddress Address of Inj token bridge contract
 * @param walletAddress Address of wallet in inj format
 * @param asset Name or address of the asset to be attested
 * For native assets the asset string is the denomination.
 * For foreign assets the asset string is the inj address of the foreign asset
 * @returns Message to be broadcast
 */
export declare function attestFromInjective(tokenBridgeAddress: string, walletAddress: string, asset: string): Promise<MsgExecuteContractInjective>;
export declare function attestFromSolana(connection: Connection, bridgeAddress: string, tokenBridgeAddress: string, payerAddress: string, mintAddress: string): Promise<Transaction>;
/**
 * Attest an already created asset
 * If you create a new asset on algorand and want to transfer it elsewhere,
 * you create an attestation for it on algorand... pass that vaa to the target chain..
 * submit it.. then you can transfer from algorand to that target chain
 * @param client An Algodv2 client
 * @param tokenBridgeId The ID of the token bridge
 * @param senderAcct The account paying fees
 * @param assetId The asset index
 * @returns Transaction ID
 */
export declare function attestFromAlgorand(client: Algodv2, tokenBridgeId: bigint, bridgeId: bigint, senderAddr: string, assetId: bigint): Promise<TransactionSignerPair[]>;
/**
 * Attest an already created asset
 * If you create a new asset on near and want to transfer it elsewhere,
 * you create an attestation for it on near... pass that vaa to the target chain..
 * submit it.. then you can transfer from near to that target chain
 * @param client An Near account client
 * @param coreBridge The account for the core bridge
 * @param tokenBridge The account for the token bridge
 * @param asset The account for the asset
 * @returns [sequenceNumber, emitter]
 */
export declare function attestTokenFromNear(client: nearAccount, coreBridge: string, tokenBridge: string, asset: string): Promise<[number, string]>;
/**
 * Attest NEAR
 * @param client An Near account client
 * @param coreBridge The account for the core bridge
 * @param tokenBridge The account for the token bridge
 * @returns [sequenceNumber, emitter]
 */
export declare function attestNearFromNear(client: nearAccount, coreBridge: string, tokenBridge: string): Promise<[number, string]>;
